@@ -1,7 +1,7 @@
 /*
  * The SIP module interface.
  *
- * Copyright (c) 2010 Riverbank Computing Limited <info@riverbankcomputing.com>
+ * Copyright (c) 2011 Riverbank Computing Limited <info@riverbankcomputing.com>
  *
  * This file is part of SIP.
  *
@@ -54,8 +54,8 @@ extern "C" {
 /*
  * Define the SIP version number.
  */
-#define SIP_VERSION         0x040c00
-#define SIP_VERSION_STR     "4.12"
+#define SIP_VERSION         0x040c02
+#define SIP_VERSION_STR     "4.12.2"
 
 
 /*
@@ -604,6 +604,7 @@ typedef enum {
 #endif
     iter_slot,          /* __iter__ */
     next_slot,          /* __next__ */
+    setattr_slot,       /* __setattr__, __delattr__ */
 } sipPySlotType;
 
 
