@@ -2,7 +2,7 @@
 # extension modules created with SIP.  It provides information about file
 # locations, version numbers etc., and provides some classes and functions.
 #
-# Copyright (c) 2010 Riverbank Computing Limited <info@riverbankcomputing.com>
+# Copyright (c) 2011 Riverbank Computing Limited <info@riverbankcomputing.com>
 #
 # This file is part of SIP.
 #
@@ -26,22 +26,23 @@ import re
 
 # These are installation specific values created when SIP was configured.
 _pkg_config = {
-    'arch':             '',
-    'default_bin_dir':  '/usr/local/bin',
-    'default_mod_dir':  '/usr/local/lib/python2.6/site-packages',
-    'default_sip_dir':  '/usr/local/share/sip',
-    'platform':         'openbsd-g++',
-    'py_conf_inc_dir':  '/usr/local/include/python2.6',
-    'py_inc_dir':       '/usr/local/include/python2.6',
-    'py_lib_dir':       '/usr/local/lib/python2.6/config',
-    'py_version':       0x020606,
-    'sip_bin':          '/usr/local/bin/sip',
-    'sip_config_args':  '-b /usr/local/bin -d /usr/local/lib/python2.6/site-packages -e /usr/local/include/python2.6 -v /usr/local/share/sip INCDIR=/usr/local/include LIBDIR=/usr/local/lib CC=cc CXX=c++ CFLAGS=-O2 -pipe  CXXFLAGS=-O2 -pipe ',
-    'sip_inc_dir':      '/usr/local/include/python2.6',
-    'sip_mod_dir':      '/usr/local/lib/python2.6/site-packages',
-    'sip_version':      0x040c00,
-    'sip_version_str':  '4.12',
-    'universal':        ''
+    'arch':               '',
+    'default_bin_dir':    '/usr/local/bin',
+    'default_mod_dir':    '/usr/local/lib/python2.7/site-packages',
+    'default_sip_dir':    '/usr/local/share/sip',
+    'deployment_target':  '',
+    'platform':           'openbsd-g++',
+    'py_conf_inc_dir':    '/usr/local/include/python2.7',
+    'py_inc_dir':         '/usr/local/include/python2.7',
+    'py_lib_dir':         '/usr/local/lib/python2.7/config',
+    'py_version':         0x020701,
+    'sip_bin':            '/usr/local/bin/sip',
+    'sip_config_args':    '-b /usr/local/bin -d /usr/local/lib/python2.7/site-packages -e /usr/local/include/python2.7 -v /usr/local/share/sip INCDIR=/usr/local/include LIBDIR=/usr/local/lib CC=cc CXX=c++ CFLAGS=-O2 -pipe  CXXFLAGS=-O2 -pipe ',
+    'sip_inc_dir':        '/usr/local/include/python2.7',
+    'sip_mod_dir':        '/usr/local/lib/python2.7/site-packages',
+    'sip_version':        0x040c02,
+    'sip_version_str':    '4.12.2',
+    'universal':          ''
 }
 
 _default_macros = {
@@ -310,7 +311,7 @@ class Makefile:
     def __init__(self, configuration, console=0, qt=0, opengl=0, python=0,
                  threaded=0, warnings=1, debug=0, dir=None,
                  makefile="Makefile", installs=None, universal=None,
-                 arch=None):
+                 arch=None, deployment_target=None):
         """Initialise an instance of the target.  All the macros are left
         unchanged allowing scripts to manipulate them at will.
 
@@ -336,6 +337,8 @@ class Makefile:
         binary.  If it is None then the value is taken from the configuration.
         arch is the space separated MacOS/X architectures to build.  If it is
         None then it is taken from the configuration.
+        deployment_target MacOS/X deployment target.  If it is None then it is
+        taken from the configuration.
         """
         if qt:
             if not hasattr(configuration, "qt_version"):
@@ -382,6 +385,11 @@ class Makefile:
         else:
             self._arch = arch
 
+        if deployment_target is None:
+            self._deployment_target = configuration.deployment_target
+        else:
+            self._deployment_target = deployment_target
+
         self._finalised = 0
 
         # Copy the macros and convert them all to instance lists.
@@ -1131,6 +1139,9 @@ class Makefile:
 
         mfile is the file object.
         """
+        if self._deployment_target:
+            mfile.write("export MACOSX_DEPLOYMENT_TARGET = %s\n" % self._deployment_target)
+
         mfile.write("CC = %s\n" % self.required_string("CC"))
         mfile.write("CXX = %s\n" % self.required_string("CXX"))
         mfile.write("LINK = %s\n" % self.required_string("LINK"))
@@ -1439,7 +1450,8 @@ class ModuleMakefile(Makefile):
     def __init__(self, configuration, build_file, install_dir=None, static=0,
                  console=0, qt=0, opengl=0, threaded=0, warnings=1, debug=0,
                  dir=None, makefile="Makefile", installs=None, strip=1,
-                 export_all=0, universal=None, arch=None):
+                 export_all=0, universal=None, arch=None,
+                 deployment_target=None):
         """Initialise an instance of a module Makefile.
 
         build_file is the file containing the target specific information.  If
@@ -1453,7 +1465,7 @@ class ModuleMakefile(Makefile):
         increases the size of the module and slows down module load times but
         may avoid problems with modules that use exceptions.  The default is 0.
         """
-        Makefile.__init__(self, configuration, console, qt, opengl, 1, threaded, warnings, debug, dir, makefile, installs, universal, arch)
+        Makefile.__init__(self, configuration, console, qt, opengl, 1, threaded, warnings, debug, dir, makefile, installs, universal, arch, deployment_target)
 
         self._build = self.parse_build_file(build_file)
         self._install_dir = install_dir
@@ -1755,7 +1767,8 @@ class SIPModuleMakefile(ModuleMakefile):
     def __init__(self, configuration, build_file, install_dir=None, static=0,
                  console=0, qt=0, opengl=0, threaded=0, warnings=1, debug=0,
                  dir=None, makefile="Makefile", installs=None, strip=1,
-                 export_all=0, universal=None, arch=None, prot_is_public=0):
+                 export_all=0, universal=None, arch=None, prot_is_public=0,
+                 deployment_target=None):
         """Initialise an instance of a SIP generated module Makefile.
 
         prot_is_public is set if "protected" is to be redefined as "public".
@@ -1766,7 +1779,8 @@ class SIPModuleMakefile(ModuleMakefile):
         """
         ModuleMakefile.__init__(self, configuration, build_file, install_dir,
                 static, console, qt, opengl, threaded, warnings, debug, dir,
-                makefile, installs, strip, export_all, universal, arch)
+                makefile, installs, strip, export_all, universal, arch,
+                deployment_target)
 
         self._prot_is_public = prot_is_public
 
@@ -1788,14 +1802,14 @@ class ProgramMakefile(Makefile):
     def __init__(self, configuration, build_file=None, install_dir=None,
                  console=0, qt=0, opengl=0, python=0, threaded=0, warnings=1,
                  debug=0, dir=None, makefile="Makefile", installs=None,
-                 universal=None, arch=None):
+                 universal=None, arch=None, deployment_target=None):
         """Initialise an instance of a program Makefile.
 
         build_file is the file containing the target specific information.  If
         it is a dictionary instead then its contents are validated.
         install_dir is the directory the target will be installed in.
         """
-        Makefile.__init__(self, configuration, console, qt, opengl, python, threaded, warnings, debug, dir, makefile, installs, universal, arch)
+        Makefile.__init__(self, configuration, console, qt, opengl, python, threaded, warnings, debug, dir, makefile, installs, universal, arch, deployment_target)
 
         self._install_dir = install_dir
 
